@@ -1,4 +1,4 @@
-#' Function to calculate Arm Ratio and C.I. and categorical morphologies
+#' Function to calculate Arm Ratio and C.I. and morphological categories
 #'
 #' This function reads a dataframe and produces AR (r), CI, Guerra and Levan
 #' classifications
@@ -27,19 +27,21 @@ armRatioCI<- function(dfOfChrSize){
   dfOfChrSize$largest <-pmax(dfOfChrSize$shortArmSize, dfOfChrSize$longArmSize)
   dfOfChrSize$AR<-format(round(dfOfChrSize$largest/dfOfChrSize$smallest,1),nsmall = 1)
   dfOfChrSize$CI<-format(round(dfOfChrSize$smallest*100/(dfOfChrSize$longArmSize+dfOfChrSize$shortArmSize),1),nsmall = 1)
-  dfOfChrSize$Guerra<-ifelse(dfOfChrSize$AR<=1.49999999999,"M",
-                             ifelse(dfOfChrSize$AR>=1.5 & dfOfChrSize$AR<=2.999999999, "SM",
-                                    ifelse(dfOfChrSize$AR>=3, "A","" )
+  dfOfChrSize$ARnum<-as.numeric(dfOfChrSize$AR)
+  dfOfChrSize$CInum<-as.numeric(dfOfChrSize$CI)
+  dfOfChrSize$Guerra<-ifelse(dfOfChrSize$ARnum<=1.49999999999,"M",
+                             ifelse(dfOfChrSize$ARnum>=1.5 & dfOfChrSize$ARnum<=2.999999999, "SM",
+                                    ifelse(dfOfChrSize$ARnum>=3, "A","" )
                                    )
                             )
-  dfOfChrSize$Levan<-ifelse(dfOfChrSize$AR==1,"M",
-                            ifelse(dfOfChrSize$AR>1 & dfOfChrSize$AR<1.7,"m",
-                              ifelse(dfOfChrSize$AR==1.7, "m-sm",
-                                  ifelse(dfOfChrSize$AR>1.7 & dfOfChrSize$AR<3, "sm",
-                                         ifelse(dfOfChrSize$AR==3,"sm-st",
-                                                ifelse(dfOfChrSize$AR>3 & dfOfChrSize$AR<7,"st",
-                                                       ifelse(dfOfChrSize$AR==7,"st-t",
-                                                              ifelse(dfOfChrSize$AR>7,"t","")
+  dfOfChrSize$Levan<-ifelse(dfOfChrSize$ARnum==1,"M",
+                            ifelse(dfOfChrSize$ARnum>1 & dfOfChrSize$ARnum<1.7,"m",
+                              ifelse(dfOfChrSize$ARnum==1.7, "m-sm",
+                                  ifelse(dfOfChrSize$ARnum>1.7 & dfOfChrSize$ARnum<3, "sm",
+                                         ifelse(dfOfChrSize$ARnum==3,"sm-st",
+                                                ifelse(dfOfChrSize$ARnum>3 & dfOfChrSize$ARnum<7,"st",
+                                                       ifelse(dfOfChrSize$ARnum==7,"st-t",
+                                                              ifelse(dfOfChrSize$ARnum>7,"t","")
                                                        )
                                                 )
                                          )
